<TS language="is" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Smelltu á hægri músatakka til að breyta færslugildi eða merkingu</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Búa til nýtt færslugildi</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nýtt</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Afrita valið færslugildi í klemmuspjald</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Afrita</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Loka</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Eyða völdu færslugildi úr listanum</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Flytja gögn í flipanum í skrá</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Flytja út</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Eyða</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Veldu færslugildi sem greiða skal til</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Veldu færslugildi sem á að taka við mynt</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Veldu</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Færslugildi sem senda frá sér</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Færslugildi sem þiggja til sín</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Þetta eru Litecoin færslugildin sem senda greiðslur. Skoðið ævinlega vel upphæðina og færslugildin sem þiggja greiðslur áður en mynt er send.</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Þetta eru Litecoin færslugildin sem þiggja greiðslur. Mælt er með að nota aldrei sama færslugildið til að þiggja fleiri en eina greiðslu.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Afrita færslugildi</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Afrita og &amp;Merkja</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Breyta</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Flytja út færslulista</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Gildi aðskilin með kommu (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Útflutningur tókst ekki</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Ekki tókst að vista færslugildalistann á %1. Reyndu aftur.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Merking</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Færslugildi</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(engin merking)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Lykilsetning</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Skráðu lykilsetningu</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Ný lykilsetning</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Endurtaktu nýja lykilsetningu</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Skráðu nýju lykilsetninguna í veskið. &lt;br/&gt;Vinsamlegast notaðu lykilsetningu með &lt;b&gt;tíu eða fleiri slembibókstöfum&lt;/b&gt;, eða &lt;b&gt;átta eða fleiri orðum&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Dulkóða veski</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Þessi aðgerð þarf að fá lykilsetninguna þína til að opna veskið.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Opna veskið</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Þessi aðgerð þarf lykilsetninguna þína til að dulráða veskið.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Dulráða veskið</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Breyta lykilsetningu</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Skráðu gömlu lykilsetninguna og þá nýju í veskið.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Staðfesta dulkóðun veskis</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR LITECOINS&lt;/b&gt;!</source>
        <translation>Viðvörun: Ef þú dulkóðar veskið og týnir lykilsetningunn þá munt þú &lt;b&gt;TAPA ALLRI ÞINNI LITECOIN MYNT&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Ertu viss um að þú viljir dulkóða veskið þitt?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Veski dulkóðað</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>MIKILVÆGT: Nýja dulkóðaða veskisskráin þarf að koma í staðinn fyrir öll fyrri afrit sem þú hefur gert af upprunalegu veskisskránni. Af öryggisástæðum munu öll fyrri afrit af ódulkóðaða veskinu verða óvirk um leið og þú byrjar að nota nýja, dulkóðaða veskið.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Dulkóðun veskis mistókst</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Dulkóðun veskis mistóks vegna innri villu. Veskið þitt var ekki dulkóðað.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Lykilsetningarnar eru ekki þær sömu.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Ekki tókst að opna veskið</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Lykilsetningin sem notuð var til að dulráða veskið var ekki rétt.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Ekki tókst að dulráða veski</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Það tókst að breyta lykilsetningu veskis.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Viðvörun: Kveikt er á HÁSTÖFUM!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Netgríma</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Bannað til</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Undirrita &amp;skilaboð</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Samstilli við netið...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Yfirlit</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Sýna almennt yfirlit af veski</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Færslur</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Skoða færslusögu</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Hætta</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Hætta í forriti</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Um %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Sýna upplýsingar um %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Um &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Sýna upplýsingar um Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Valkostir...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Breyta samstillingum fyrir %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Dulkóða veski...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Öryggisafrit á veski...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Breyta lykilsetningu</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Opna &amp;URL...</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>Smelltu til að loka fyrir netumferð.</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>Slökkt á netumferð.</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>Smelltu til að hefja aftur netumferð.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Samstilli hausa (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Endurraða blokkum á drifi...</translation>
    </message>
    <message>
        <source>Send coins to a Litecoin address</source>
        <translation>Senda mynt í Litecoin færslugildi</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Öryggisafrita veski á annan stað</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Breyta lykilsetningunni sem gildir um dulkóðun veskis</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Kembunargluggi</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Opna kembunar- og greiningarstjórnborð</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Yfirfara skilaboð...</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Senda</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Taka við</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Sýna / Fela</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Sýna eða fela megin glugga</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Dulkóða einkalyklana sem tilheyra veskinu þínu</translation>
    </message>
    <message>
        <source>Sign messages with your Litecoin addresses to prove you own them</source>
        <translation>Kvitta undir skilaboð með Litecoin færslugildunum þínum til að sanna að þú eigir þau</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Litecoin addresses</source>
        <translation>Yfirfara skilaboð til að tryggja að kvittað hafi verið fyrir þau með tilteknum Litecoin færslugildum</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Skrá</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Stillingar</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjálp</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Tólaborð flipa</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and litecoin: URIs)</source>
        <translation>Óska eftir greiðslum (býr til QR kóða og litecoin: URI)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Sýna lista yfir færslugildi sem notuð hafa verið til sendingar og merkingar þeirra</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Sýna færslugildi sem notuð hafa verið til að taka við mynt og merkingar þeirra</translation>
    </message>
    <message>
        <source>Open a litecoin: URI or payment request</source>
        <translation>Opna litecoin: URI eða greiðslubeiðni</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Raða blokkum á drifi</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Vinn úr blokkum á drifi...</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 á eftir</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Síðasta viðtekna blokk var búin til fyrir %1 síðan.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Færslur á eftir þessari munu ekki sjást.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Villa</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Viðvörun</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Upplýsingar</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Uppfært</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Litecoin command-line options</source>
        <translation>Sýna %1 hjálparskilaboðin til að fá lista yfir valkosti Litecoin aðgerðir í skipanalínu</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 biðlarar</translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>Tengist jafningjum...</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Færist nær...</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Dagsetning: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Upphæð: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Tegund: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Merki: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Færslugildi: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Send færsla</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Móttökufærsla</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation>HD lyklagerð er &lt;b&gt;virkjuð&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>HD lyklagerð er &lt;b&gt;óvirk&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Veskið er &lt;b&gt;dulkóðað&lt;/b&gt; og núna &lt;b&gt;ólæst&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Veskið er &lt;b&gt;dulkóðað&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</translation>
    </message>
    <message>
        <source>A fatal error occurred. Litecoin can no longer continue safely and will quit.</source>
        <translation>Alvarleg villa átti sér stað. Litecoin getur ekki haldið áfram með öruggum hætti og stoppar hér.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Myntval</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Magn:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bæti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Upphæð:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Gjald:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Ryk:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Eftirgjald:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Skiptimynt:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>(af)velja allt</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Hrísluhamur</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Listahamur</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Upphæð</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Móttekið með merkingu</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Móttekið með færslugildi</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Afrita færslugildi</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Afrita merki</translation>
    </message>
    <message>
        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
        <translation>Þetta merki verður rautt ef einhver viðtakandi tekur við upphæð sem er lægri en núgildandi þröskuldur.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ekkert merki)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Breyta færslugildi</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Merki</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>Merking tengd þessu færslugildi</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>Færslugildið sem tengt er þessari færslu. Þessu má einungis breyta þegar sent er.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Nýtt móttökufærslugildi</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nýtt sendingarfærslugildi</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Breyta móttökufærslugildi</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Breyta sendingarfærslugildi</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Litecoin address.</source>
        <translation>Færslugildið sem slegið var inn "%1" er ekki leyfilegt Litecoin færslugildi.</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Villa</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Number of blocks left</source>
        <translation>Fjöldi blokka sem eftir eru</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Tími síðustu blokkar</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>IP tala staðgengils (t.d. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Third party URLs (e.g. a block explorer) that appear in the transactions tab as context menu items. %s in the URL is replaced by transaction hash. Multiple URLs are separated by vertical bar |.</source>
        <translation>URL frá þriðja aðila (t.d. blokkarskoðari) sem birtast í færsluflipanum sem samhengisatriði. %s í URL-inu skipt út fyrir færslutvíkross. Mörg URL eru aðskilin með lóðréttu striki |.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Villa</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Uppgefið færslugildi staðgengils er ógilt.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation>Námuunnin innistæða sem hefur enn ekki komið fram</translation>
    </message>
    <message>
        <source>Your current balance in watch-only addresses</source>
        <translation>Innistæða færslugilda sem eru einungis til skoðunar</translation>
    </message>
    <message>
        <source>Unconfirmed transactions to watch-only addresses</source>
        <translation>Óstaðfestar færslur til færslugilda sem eru einungis til skoðunar</translation>
    </message>
    <message>
        <source>Mined balance in watch-only addresses that has not yet matured</source>
        <translation>Námuunnin innistæða á færslugildum sem eru einungis til skoðunar og hafa ekki komið fram</translation>
    </message>
    <message>
        <source>Current total balance in watch-only addresses</source>
        <translation>Innistæða á færslugildum sem eru einungis til skoðunar</translation>
    </message>
</context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Invalid payment address %1</source>
        <translation>Ógilt færslugildi til greiðslu %1</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Upphæð</translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Block chain</source>
        <translation>Blokkarkeðja</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Núverandi fjöldi blokka</translation>
    </message>
    <message>
        <source>Starting Block</source>
        <translation>Upphafsblokk</translation>
    </message>
    <message>
        <source>Synced Blocks</source>
        <translation>Samhæfðar blokkir</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Tími síðustu blokkar</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Merki:</translation>
    </message>
    <message>
        <source>An optional label to associate with the new receiving address.</source>
        <translation>Valfrjálst merki sem tengist nýju móttökufærslutölunni.</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Afrita merki</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Vistfang</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Upphæð</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Merki</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Veski</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>URI varð of langt, reyndu að minnka texta í merki / skilaboðum.</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>Merki</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ekkert merki)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Magn:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bæti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Upphæð:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Gjald:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Eftirgjald:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Skiptimynt:</translation>
    </message>
    <message>
        <source>(Smart fee not initialized yet. This usually takes a few blocks...)</source>
        <translation>(Smart gjald er ekki gangsett ennþá. Þetta tekur venjulega nokkrar blokkir...)</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Ryk:</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ekkert merki)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Merki:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Generated coins must mature %1 blocks before they can be spent. When you generated this block, it was broadcast to the network to be added to the block chain. If it fails to get into the chain, its state will change to "not accepted" and it won't be spendable. This may occasionally happen if another node generates a block within a few seconds of yours.</source>
        <translation>Fullgerð mynt verður að nýta %1 blokkir. Þegar þú bjóst til þessa blokk, þá var jafnóðum tilkynnt á netinu að hún eigi að bætast við blokkakeðjuna. Ef hún kemst ekki í keðjuna þá mun staða hennar breytast í "ósamþykkt" og ekki verður hægt að nota hana. Þetta gerist annað slagið ef annar hnútpunktur klárar blokk nokkrum sekúndum á undan þinni.</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Upphæð</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>Merki</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Námuunnið</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ekkert merki)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Mined</source>
        <translation>Námuunnið</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Afrita færslugildi</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Afrita merki</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Gildi aðskilin með kommu (*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Merki</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Vistfang</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Útflutningur tókst ekki</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Flytja út</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Flytja gögn í flipanum í skrá</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error reading %s! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Villa við lestur %s! Allir lyklar fóru inn á réttan hátt, en færslugögn eða færslugildi gætu verið röng eða horfin.</translation>
    </message>
    <message>
        <source>Warning: The network does not appear to fully agree! Some miners appear to be experiencing issues.</source>
        <translation>Viðvörun: Netið er ekki í fullu samræmi! Einhver námuvinnsla virðist í ólagi.</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Upplýsingar</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Viðvörun</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Villa</translation>
    </message>
</context>
</TS>